@@ -2,11 +2,11 @@ package RFID::Libnfc::Tag;
 
 use strict;
 
-use RFID::Libnfc qw(nfc_configure nfc_initiator_select_tag nfc_initiator_deselect_tag);
+use RFID::Libnfc qw(nfc_configure nfc_initiator_select_passive_target nfc_initiator_deselect_target);
 use RFID::Libnfc::Constants;
 use Data::Dumper;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 my %types = (
     scalar(IM_ISO14443A_106) => 'RFID::Libnfc::Tag::ISO14443A_106'
@@ -37,9 +37,9 @@ sub new {
     # Enable field so more power consuming cards can power themselves up
     nfc_configure($reader->pdi, DCO_ACTIVATE_FIELD, 1);
 
-    if (!nfc_initiator_select_tag($reader->pdi, $type, 0, 0, $self->{_pti}))
+    if (!nfc_initiator_select_passive_target($reader->pdi, $type, 0, 0, $self->{_pti}))
     {
-        $self->{_last_error} = "No tag was found";
+        #warn "No tag was found";
         return undef;
     } else {
         print "Card:\t ".(split('::', $types{$type}))[2]." found\n" if $self->{debug};
@@ -80,7 +80,7 @@ sub AUTOLOAD {
 
 sub DESTROY {
     my $self = shift;
-    nfc_initiator_deselect_tag($self->reader->pdi);
+    nfc_initiator_deselect_target($self->reader->pdi);
 }
 
 # number of blocks on the tag
