@@ -3,10 +3,10 @@ package RFID::Libnfc::Tag::ISO14443A_106::Classic::MINI;
 use strict;
 
 use base qw(RFID::Libnfc::Tag::ISO14443A_106::Classic);
-use RFID::Libnfc qw(nfc_initiator_select_tag nfc_initiator_mifare_cmd print_hex);
+use RFID::Libnfc;
 use RFID::Libnfc::Constants;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 # number of blocks in the tag
 sub blocks {
